<?php
/** 
 *	Aero Custom Functions
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki Aria Gumelar
 *	@version	: 1.0
 *	@link		: http://www.my-themes.com
 *
 *	@copyright	: Copyright (c) 2012, http://www.my-themes.com
 *	--------------------------------------------------------------------------- */

/*	Function to get theme options
 *	---------------------------------------- */
	if ( ! function_exists( 'aero_get_option' ) ) :
	function aero_get_option( $name, $default = false ) {
		$config = get_option( 'aeroframework' );
		$prefix = preg_replace( "/\W/" , "", strtolower( THEMENAME ) );
		$n = $prefix . '_' . $name;
		
		if ( !isset($config['id']) ) {
			return $default;
		}
		
		$options = get_option($config['id']);

		if ( isset($options[$n]) ) {
			return $options[$n];
		}
		
		return $default;
	}
	endif;
	
/*	Function add more classes into post_class
 *	---------------------------------------- */
	add_filter('post_class', 'aero_additional_post_classes');
	
	function aero_additional_post_classes( $class ) {
		if ( is_singular() ): 
			$class[] = 'singular-entry'; // if is_singular post put "singular-entry" class.
		else :
			$class[] = 'entry'; // if is global post put "entry" class.
		endif;
		
		$class[] = 'clearfix'; // and it's an helper class to clear floated elements.
	
		return $class; // return it.
	}
	
/*	Function add post wrapper classes
 *	---------------------------------------- */
	function aero_post_box_class() {
		global $post_num;

		if ( ++$post_num % 2 )
			$class = 'alpha'; 
		else
			$class = 'omega';

		echo $class;
	}
	
/*	Function add more classes into <body> tag
 *	---------------------------------------- */
	add_filter('body_class', 'aero_browser_body_class');

	function aero_browser_body_class($class) {
		global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
	
		if($is_lynx) 
		$class[] = 'lynx';
		elseif($is_gecko) 
		$class[] = 'gecko';
		elseif($is_opera) 
		$class[] = 'opera';
		elseif($is_NS4) 
		$class[] = 'ns4';
		elseif($is_safari) 
		$class[] = 'safari';
		elseif($is_chrome) 
		$class[] = 'chrome';
		elseif($is_IE) 
		$class[] = 'ie';
		elseif($is_iphone) 
		$class[] = 'iphone';
		else 
		$class[] = 'unknown';
		
		return $class;
	}
	
/*	Function to create custom excerpt lenght
 *	---------------------------------------- */	
	if ( ! function_exists('aero_excerpt') ) :
	function aero_excerpt($lenght) {
		$limit = $lenght + 1;
		$excerpt = explode(' ', get_the_excerpt(), $limit);
		array_pop($excerpt);
		$excerpt = implode(' ', $excerpt) . '...';
		
		echo $excerpt;
	}
	endif;
	
/*	Function to get attachment id from attachment url
 *	---------------------------------------- */
	if ( ! function_exists('aero_get_attachment_id') ) :
	function aero_get_attachment_id($url) {
		global $wpdb;	
		$query = "SELECT ID FROM {$wpdb->posts} WHERE guid='$url'";	
		return $wpdb->get_var($query);
	}
	endif;
	
/*	Function to print the thumbnail
 *	---------------------------------------- */
	
	function aero_print_thumbnail($args= '') {	
		global $post;
		
		/* default args */
		$defaults = array (
			'ID' => $post->ID,
			'size' => '270x155',
			'type' => '', 
		);
		
		/* parse the args */
		$x = wp_parse_args ( $args, $defaults );
		$post_id = $x['ID'];
		$size = $x['size'];
		$type = $x['type'];
		
		if ( (function_exists('has_post_thumbnail')) && (has_post_thumbnail()) ) {
			
			$thumbnail_id = get_post_thumbnail_id($post_id); // thumbnail ID.
			$thumbnail = wp_get_attachment_image($thumbnail_id, $size); // thumbnail.
			$thumbnail_full = wp_get_attachment_image_src($thumbnail_id, 'full'); // thumbnail full size.
			$thumbnail_full_url = $thumbnail_full[0]; // thumbnail full url.
			$thumbnail_link = get_attachment_link($thumbnail_id);
			$thumbnail_post = get_posts( array('p' => $thumbnail_id, 'post_type' => 'attachment') );
			
			if ( $thumbnail_post && isset( $thumbnail_post[0] ) ) {
				$thumbnail_title = $thumbnail_post[0]->post_title;
			} else {
				$thumbnail_title = get_the_title($post_id);
			}
			
			if ($type  == 'link') {
				$result = '<a href="'.get_permalink($post_id).'" title="'.get_the_title($post_id).'">'.$thumbnail.'</a>';
			} elseif ($type == 'lightbox') {
				$result = '<a href="'.$thumbnail_full_url.'" title="'.get_the_title($post_id).'" rel="prettyPhoto">'.$thumbnail.'</a>';
			} elseif ($type == 'special') {
				$result = '<a class="expander" href="'.$thumbnail_full_url.'" title="'.$thumbnail_title.'" rel="prettyPhoto"><span>zoom</span></a>'.$thumbnail;
			} elseif ( $type == 'gallery' ) {
				$result = '<a class="expander" href="'.$thumbnail_full_url.'" title="'.$thumbnail_title.'" rel="prettyPhoto"><span>zoom</span></a><a class="post-format-icon" href="'.$thumbnail_link.'" title="'.$thumbnail_title.'"><span>Link</span></a>'.$thumbnail;
			} else {
				$result = $thumbnail;
			}
			
		} else {
		
			$result = '';
			
		}
		
		return $result;
	}
	
/*	Function to print the video thumbnail
 *	---------------------------------------- */
	function aero_print_video_thumbnail($args = '') {
		global $post;
		
		/* default args */
		$defaults = array (
			'ID' => $post->ID,
			'engine' => '', 
			'video_url' => '', 
			'width' => 580, 
			'height' => 333,
			'link' => '',
		);
		
		/* timthumb location */
		$tt = AERO_FRAMEWORK_DIRECTORY . 'plugins/timthumb.php';
		
		/* parse the args */
		$x = wp_parse_args ( $args, $defaults );
		$post_id = $x['ID'];
		$engine = $x['engine'];
		$video_url = $x['video_url'];
		$width = $x['width'];
		$height = $x['height'];
		$link = $x['link'];
		
		if ( $engine == 'youtube' ) :
			$thumb = aero_get_youtube_data( $video_url, 'thumbnail' ); 
			$title = aero_get_youtube_data( $video_url, 'title' ); 
		elseif ( $engine == 'vimeo' ) :
			$thumb = aero_get_vimeo_data( $video_url, 'thumbnail_large' );
			$title = aero_get_vimeo_data( $video_url, 'title' );
		else :
			$thumb = '';
			$title = '';
		endif;
		
		if ( $link == 'post' ) :
			$thumbnail = '<a href="'.get_permalink($post_id).'" title="'.get_the_title($post_id).'"><img src="'.$tt.'?src='.$thumb.'&amp;w='.$width.'&amp;h='.$height.'" width="'.$width.'" height="'.$height.'" alt="'.$title.'"/></a>';
		elseif ($link == 'source' ) :
			$thumbnail = '<a href="'.$video_url.'" title="'.$$title.'"><img src="'.$tt.'?src='.$thumb.'&amp;w='.$width.'&amp;h='.$height.'" width="'.$width.'" height="'.$height.'" alt="'.$title.'"/></a>';
		else :
			$thumbnail = '<img src="'.$tt.'?src='.$thumb.'&amp;w='.$width.'&amp;h='.$height.'" width="'.$width.'" height="'.$height.'" alt="'.$title.'"/>';
		endif;
		
		return $thumbnail;
	}

/*	Function to print the audio player
 *	---------------------------------------- */
	function aero_print_audio_player($args = '') {
		global $post;
		
		/* default args */
		$defaults = array (
			'ID' => $post->ID,
			'prefix' => 'audio',
			'file' => '',
			'additional_file' => '',
			'format' => '',
		);
		
		$x = wp_parse_args ( $args, $defaults );
		$post_id = $x['ID'];
		$prefix = $x['prefix'];
		$file = $x['file'];
		$additional_file = $x['additional_file'];
		$format = $x['format'];
		
		if($file) {
			
			echo '<div id="jplayer_'.$prefix.'_'.$post_id.'" class="jp-jplayer"></div>';
			echo '<div class="jp-audio">';
				echo '<div id="jp_interface_'.$prefix.'_'.$post_id.'" class="jp-interface">';
					echo '<ul class="jp-controls">';
						echo '<li><a href="#" class="jp-play" tabindex="1">play</a></li>';
						echo '<li><a href="#" class="jp-pause" tabindex="1">pause</a></li>';
						echo '<li><a href="#" class="jp-mute" tabindex="1">mute</a></li>';
						echo '<li><a href="#" class="jp-unmute" tabindex="1">unmute</a></li>';
					echo '</ul>';
					echo '<div class="jp-progress-container">';
						echo '<div class="jp-progress">';
							echo '<div class="jp-seek-bar">';
								echo '<div class="jp-play-bar"></div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
					echo '<div class="jp-volume-bar-container">';
						echo '<div class="jp-volume-bar">';
							echo '<div class="jp-volume-bar-value"></div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>'; ?>
			<script type="text/javascript">
			//<![CDATA[
			jQuery(document).ready(function(){
				jQuery("#jplayer_<?php echo $prefix . '_' . $post_id; ?>").jPlayer({
					ready: function () {
						jQuery(this).jPlayer("setMedia", {
							<?php echo $format; ?>:"<?php echo $file; ?>",
							<?php if($additional_file) : ?>
							oga: "<?php echo $additional_file; ?>",
							<?php endif; ?>
						});
					},
					swfPath: "<?php echo get_template_directory_uri(); ?>/javascripts/jplayer",
					cssSelectorAncestor: "#jp_interface_<?php echo $prefix . '_' . $post_id; ?>",
					supplied:"<?php echo $format; if($additional_file) : ?>,oga<?php endif; ?>"
				});
			});
			//]]>
			</script>
			<?php
		}
	}
	
/*	Function to print the video player
 *	---------------------------------------- */
	function aero_print_video_player($args = '') {
		global $post;
		
		/* default args */
		$defaults = array (
			'ID' => $post->ID,
			'engine' => '', 
			'video_id' => '', 
			'width' => 620, 
			'height' => 300, 
		);
		
		$x = wp_parse_args ( $args, $defaults );
		$post_id = $x['ID'];
		$engine = $x['engine'];
		$video_id = $x['video_id'];
		$width = $x['width'];
		$height = $x['height'];
		
		if ( $engine == 'youtube' ) :
			$player = '<iframe width="'.$width.'" height="'.$height.'" src="http://www.youtube.com/embed/'.$video_id.'" frameborder="0" allowfullscreen></iframe>';
		elseif ( $engine == 'vimeo' ) :
			$player = '<iframe src="http://player.vimeo.com/video/'.$video_id.'?title=0&amp;byline=0&amp;portrait=0" width="'.$width.'" height="'.$height.'" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>';
		else :
			$player = '';
		endif;
		
		return $player;
	}
	
/*	Function to get video id from video url
 *	---------------------------------------- */
	function aero_get_video_id($source) {
		if (preg_match('%(?:youtube\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/ ]{11})%i', $source, $match ) ) :
			$output = $match[1];
		elseif (preg_match( '/(\d+)/', $source, $match )) :
			$output = $match[0];
		endif;
		
		// returning output
		return $output;
	}
	
/*	Function to get vimeo data
 *	---------------------------------------- */
	function aero_get_vimeo_data($source, $data) {
		
		// get the video id
		if ( preg_match('/(\d+)/', $source, $match) )
		$videoid = $match[0];
		
		// access to vimeo API
		$query = "http://vimeo.com/api/v2/video/$videoid.php";
		$hash = unserialize( file_get_contents($query) );
		
		// returning data
		return $hash[0][$data]; 
	}

/*	Function to get youtube video data
 *	---------------------------------------- */	
	function aero_get_youtube_data($source, $data) {
		// get the video id
		if( preg_match( '%(?:youtube\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/ ]{11})%i', $source, $match ) )
		$videoid = $match[1];	
		
		// access to youtube API
		$url = 'http://gdata.youtube.com/feeds/api/videos/'.$videoid ;
		$sxml = simplexml_load_file( $url );
		$namespaces = $sxml->getNameSpaces(true);
		$media = $sxml->children($namespaces['media']);
		
		// get video thumbnail
		if($media) :
		$attrs = $media->group->thumbnail[0]->attributes();
		$thumbnail = $attrs['url']; 
		else :
		$thumbnail = 'http://i.ytimg.com/vi/'.$videoid.'/0.jpg';
		endif; 
	  
		// get video player URL
		$attrs = $media->group->player->attributes();
		$watch = $attrs['url']; 
		
		// get <yt:stats> node for viewer statistics
		$yt = $sxml->children('http://gdata.youtube.com/schemas/2007');
		$attrs = $yt->statistics->attributes();
		$viewCount = $attrs['viewCount']; 
      
		// get <gd:rating> node for video ratings
		$gd = $sxml->children('http://schemas.google.com/g/2005'); 
		if ($gd->rating) {
			$attrs = $gd->rating->attributes();
			$rating = $attrs['average']; 
		} else {
			$rating = 0; 
		} 
		
		// get description
		$desc = $media->group->description;
		$author = $sxml->author->name;
	  
		if ($data == 'title') :
			$output = $sxml->title;
		elseif ($data == 'thumbnail') :
			$output = $thumbnail;
		elseif ($data == 'desc') :
			$output = $desc;
		elseif ($data == 'author') :
			$output = $author;
		elseif ($data == 'rating') :
			$output = $rating;
		elseif ($data == 'url') :
			$output = $watch;
		elseif ($data == 'views') :
			$output = $viewCount;
		endif;
		
		// returning output
		return $output;
	}
	
/*	Function to print entry as list.
 *	---------------------------------------- */	
	function aero_print_entry_list() {
	
		global $post, $post_custom_meta, $post_format_meta;
		$meta_format = get_post_meta(get_the_ID(), $post_format_meta->get_the_id(), true);
		$meta_custom = get_post_meta(get_the_ID(), $post_custom_meta->get_the_id(), true);
		
		/* Thumbnail settings */
		$width = 55;
		$height = 55;
		$size = $width.'x'.$height;
		
		echo '<li>' . "\n";
		echo '<article class="clearfix">' . "\n";
		echo '<div class="entry-image">' . "\n";
		
		$format = get_post_format($post->ID); // get post format.
		switch ($format) {
			case 'video':
	
				$engine = $meta_format['video_source'];
				$url = $meta_format['video_url'];
				$display = $meta_format['video_display'];
			
				/* Set title and thumbnail for each engines */
				if ( $engine == 'vimeo' ) :
					$title = aero_get_vimeo_data( $url, 'title' );
					$thumb = aero_get_vimeo_data( $url, 'thumbnail_large' );
				else :
					$title = aero_get_youtube_data( $url, 'title' );
					$thumb = aero_get_youtube_data( $url, 'thumbnail' ); 
				endif;
										
				if ( $display == 'vthumb' ) : // if this post ordered to display thumbnail from video.
					echo aero_print_video_thumbnail('engine='.$engine.'&video_url='.$url.'&width='.$width.'&height='.$height.'&link=post');
				else : // else
					echo aero_print_thumbnail('size='.$size.'&type=link');
				endif;
										
			break;
									
			default :
				echo aero_print_thumbnail('size='.$size.'&type=link');
			break;
		}
		echo '</div>' . "\n";
		echo '<div class="entry-details clearfix">' . "\n";
		echo '<h5 class="entry-title"><a href="'.get_permalink($post->ID).'" title="'.get_the_title($post->ID).'" rel="bookmark">'.get_the_title($post->ID).'</a></h5>' . "\n";
		echo '<div class="entry-meta">' . "\n";
		the_time(get_option('date_format')) . "\n";
		if ( comments_open() && ! post_password_required() ) : 
		echo ' - '; comments_popup_link(__('No comments', TXTDOMAIN ), __('1 comment', TXTDOMAIN ), __('%  comments', TXTDOMAIN ));
		else :
		echo ' - Comment off';
		endif;
		echo '</div>' . "\n";
		echo '</div>' . "\n";
		echo '</article><!-- #post-'.get_the_id($post->ID).'-->' . "\n";
		echo '</li>' . "\n";
	
	}
	
/*	Put theme options value to wp_head
 *	---------------------------------------- */
	add_action('wp_head', 'aero_wp_head');

	function aero_wp_head() {
		
		// custom favicon.
		$custom_favicon = aero_get_option('custom_favicon');
		
		if (!$custom_favicon == '') {
			echo '<link rel="shortcut icon" href="'. $custom_favicon .'"/>'."\n";
		}
		
		// custom css.
		$custom_css = aero_get_option('custom_css');
		
		if (!$custom_css == '') {
			echo "\n<style type=\"text/css\">\n";
			echo $custom_css;
			echo "\n</style>\n";
		}

	}

/*	Put theme options value to wp_head
 *	---------------------------------------- */	
	add_action('wp_footer', 'aero_wp_footer');
	
	function aero_wp_footer() {
		$footer_analitycs = aero_get_option('footer_analitycs');
		
		if( ! $footer_analitycs == '' ) {
			echo "\n<script type=\"text/javascript\">\n" . $footer_analitycs . "\n</script>\n";
		}
		
		wp_enqueue_style( 'responsive' );
	}
	
/*	Add extra fields on user profile setting
 *	---------------------------------------- */
	
	function extra_user_profile_fields($user) { ?>
	
		<h3><?php _e('Extra profile information', TXTDOMAIN); ?></h3>
		<table class="form-table">
		
			<tr>
				<th><label for="fb-username"><?php _e( 'Facebook Username', TXTDOMAIN); ?></label></th>
				<td>
					<input type="text" name="fb-username" id="fb-username" value="<?php echo esc_attr( get_user_meta( $user->ID, 'fb-username', true ) ); ?>" class="regular-text" /><br />
					<span class="description"><?php _e("Please enter your facebook username."); ?></span>
				</td>
			</tr>
			
			<tr>
				<th><label for="twitter-username"><?php _e( 'Twitter Username', TXTDOMAIN); ?></label></th>
				<td>
					<input type="text" name="twitter-username" id="twitter-username" value="<?php echo esc_attr( get_user_meta( $user->ID, 'twitter-username', true ) ); ?>" class="regular-text" /><br />
					<span class="description"><?php _e("Please enter your twitter username."); ?></span>
				</td>
			</tr>
				
		</table>
	<?php 
	}
	
	add_action( 'show_user_profile', 'extra_user_profile_fields' );
	add_action( 'edit_user_profile', 'extra_user_profile_fields' );
	
	function save_extra_user_profile_fields( $user_id ) {
		
		if ( !current_user_can( 'edit_user', $user_id ) ) { 
			return false; 
		}
 
		if ( isset($_POST['fb-username'])) {
			$fb_username = $_POST['fb-username'];
		}
		
		if ( isset($_POST['twitter-username'])) {
			$twitter_username = $_POST['twitter-username'];
		}
		
		update_user_meta( $user_id, 'fb-username', $fb_username );
		update_user_meta( $user_id, 'twitter-username', $twitter_username );
	}
	
	add_action( 'personal_options_update', 'save_extra_user_profile_fields' );
	add_action( 'edit_user_profile_update', 'save_extra_user_profile_fields' );
	
/*	Remove [...] on excerpt
 *	---------------------------------------- */
	function aero_auto_excerpt_more( $more ) {
		return ' &hellip;';
	}
	add_filter( 'excerpt_more', 'aero_auto_excerpt_more' );
	
/*	Plugin Name: Social Counter Widget
	Plugin URI: http://www.webdev3000.com/
	Description: This widget will display your RSS subscribers, Twitter followers and Facebook fans in one nice looking box.
	Author: Csaba Kissi
	Version: 0.8.1
	Author URI: http://www.webdev3000.com/
 *	---------------------------------------- */

	class SubscriberStats{
		
		public	$twitter,$rss;
		public	$services = array();

		public function __construct($arr){

			$this->services = $arr;

			if(trim($arr['feedBurnerURL'])) {
				$query = "http://feedburner.google.com/api/awareness/1.0/GetFeedData?dates=".date('Y')."-".date('m')."-".date("d", mktime(0, 0, 0, date("m"),date("d")-2,date("Y")))."&uri=".$arr['feedBurnerURL'];
				$xml = file_get_contents($query);
				$profile = new SimpleXmlElement($xml, LIBXML_NOCDATA);
				$this->rss = (string) $profile->feed->entry['circulation'];
				//echo '#1#'.$this->rss."*";
			}
			if(trim($arr['twitterName'])) {
				$query = 'http://api.twitter.com/1/users/show.json?screen_name='.$arr['twitterName'];
				$result = json_decode(file_get_contents($query));
				$this->twitter = $result->followers_count;
				//echo '#2#'.$this->twitter."*";
			}
		}

		public function generate(){
		
			$total = number_format($this->rss+$this->twitter);
			
			echo '<ul class="social-counter">' . "\n";
			if ($this->services['feedBurnerURL']) :
			echo '<li class="rss-counter"><a href="http://feeds.feedburner.com/'.$this->services['feedBurnerURL'].'"><span>'. number_format($this->rss) .'</span>Subscribers</a></li>' . "\n";
			endif;
			if ($this->services['twitterName']) :
			echo '<li class="twitter-counter"><a href="http://twitter.com/'.$this->services['twitterName'].'"><span>'. number_format($this->twitter) .'</span>Followers</a></li>' . "\n";
			endif;
			echo '</ul>' . "\n";
			
		}
	}
	
?>