<?php
/** 
 *	Aero General Functions
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki Aria Gumelar
 *	@version	: 1.0
 *	@link		: http://www.my-themes.com
 *	@copyright	: Copyright (c) 2012, http://www.my-themes.com
 *	--------------------------------------------------------------------------- */
 
/*	Add Theme Supports
 *	---------------------------------------- */
 
	// Add support for a variety of post formats
	add_theme_support('post-formats', array( 'audio', 'image', 'video' ));
	
	// Add default posts and comments RSS feed links to <head>.
	add_theme_support('automatic-feed-links');
	
	// Add support for featured image.
	if ( function_exists('add_theme_support') ) {
		add_theme_support('post-thumbnails'); 
	}
	
/*	Register WP nav menus
 *	---------------------------------------- */
	if ( function_exists('register_nav_menus') ) { // make sure your WordPress version supported for wp_nav_menus.
		register_nav_menus(
			array(
				'primary_menu' => 'Primary Menu', // register primary nav menu.
				'bottom_menu' => 'Bottom Menu' // register footer menu.
			)
		);
	}

/*	Register Widgets Area
 *	---------------------------------------- */	
	add_action( 'widgets_init', 'aero_widgets_init' );
	
	function aero_widgets_init() {
		register_sidebar( array(
			'name'			=> __( 'Sidebar', TXTDOMAIN ),
			'id'			=> 'sidebar',
			'description'	=> __( 'The general sidebar widget area', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Page Sidebar', TXTDOMAIN ),
			'id'			=> 'sidebar-page',
			'description'	=> __( 'The page sidebar widget area', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Portfolio Sidebar', TXTDOMAIN ),
			'id'			=> 'sidebar-portfolio',
			'description'	=> __( 'The portfolio page sidebar widget area', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget One', TXTDOMAIN ),
			'id'			=> 'sidebar-footer-1',
			'description'	=> __( 'The sidebar widget area for your site footer', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget Two', TXTDOMAIN ),
			'id'			=> 'sidebar-footer-2',
			'description'	=> __( 'The sidebar widget area for your site footer', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget Three', TXTDOMAIN ),
			'id'			=> 'sidebar-footer-3',
			'description'	=> __( 'The sidebar widget area for your site footer', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget Four', TXTDOMAIN ),
			'id'			=> 'sidebar-footer-4',
			'description'	=> __( 'The sidebar widget area for your site footer', TXTDOMAIN ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="widget-title"><span>',
			'after_title'	=> '</span></h3>',
		));
	}
	
/*	Load Theme Stylesheets
 *	---------------------------------------- */	
	add_action('wp_enqueue_scripts', 'aero_theme_stylesheets');
	
	function aero_theme_stylesheets() {
		/* register styles */
		wp_register_style('editor_style', get_template_directory_uri() . '/editor-style.css', false, THEMEVERSION, 'all' );
		wp_register_style('custom_style', get_template_directory_uri() . '/custom-style.php', false, THEMEVERSION, 'all' );
		wp_register_style('prettyPhoto', get_template_directory_uri() . '/stylesheets/prettyPhoto.css', false, '3.1.3', 'screen, projection' );
		wp_register_style('shortcodes', get_template_directory_uri() . '/stylesheets/shortcodes.css', false, THEMEVERSION, 'all' );
		wp_register_style('responsive', get_template_directory_uri() . '/stylesheets/responsive.css', false, THEMEVERSION, 'all' );
		
		/* enqueue registered styles */
		wp_enqueue_style('custom_style');
		wp_enqueue_style('editor_style');
		wp_enqueue_style('shortcodes');
		wp_enqueue_style('prettyPhoto');
	}

/*	Load Theme Scripts
 *	---------------------------------------- */	
	add_action('wp_enqueue_scripts', 'aero_theme_scripts');
	
	function aero_theme_scripts() {
		
		wp_enqueue_script('jquery');
		wp_enqueue_script('modernizr', get_template_directory_uri() . '/javascripts/modernizr.js', false, '2.3.5');
		wp_enqueue_script('superfish', get_template_directory_uri() . '/javascripts/superfish.js', false, '1.4.8');
		wp_enqueue_script('flexslider', get_template_directory_uri() . '/javascripts/jquery.flexslider.js', false, '1.8');
		wp_enqueue_script('jplayer', get_template_directory_uri() . '/javascripts/jplayer/jquery.jplayer.min.js', false, '2.1.0');
		wp_enqueue_script('pretty-photo', get_template_directory_uri() . '/javascripts/jquery.prettyPhoto.js', false, '1.3.4');
		wp_enqueue_script('cssfx', get_template_directory_uri() . '/javascripts/cssfx.js', false, '0.9.3');
		wp_enqueue_script('plugins', get_template_directory_uri() . '/javascripts/plugins.js', false, THEMEVERSION);
		wp_enqueue_script('custom', get_template_directory_uri() . '/javascripts/scripts.js', false, THEMEVERSION);
		
		/* If is contact page */
		if ( is_page_template( 'template-contact.php' ) ) {
			wp_enqueue_script('validate-contact-form', get_template_directory_uri() . '/javascripts/validate-contact-form.js', false, THEMEVERSION);
		}
		
		/* If is single and comment is allowed */
		if ( is_singular() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
		
	}
	
/*	Comment Template
 *	---------------------------------------- */	
	if ( ! function_exists( 'aero_comment' ) ) : // check if function is not exists then call the comment template.
	
	function aero_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' : ?>
		
			<li class="post pingback">
				<p><?php _e( 'Pingback:', TXTDOMAIN ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', TXTDOMAIN ), '<span class="edit-link">', '</span>' ); ?></p>
			
			<?php
			break;
		
			default : ?>
		
			<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
				<article id="comment-<?php comment_ID(); ?>" class="comment">
					<footer class="comment-meta">
						<div class="comment-author vcard">
							<?php
							$avatar_size = 68;
							if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

							echo get_avatar( $comment, $avatar_size );

							/* translators: 1: comment author, 2: date and time */
							printf( __( '%1$s on %2$s <span class="says">said: </span>', TXTDOMAIN ),
								sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
								sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
									esc_url( get_comment_link( $comment->comment_ID ) ),
									get_comment_time( 'c' ),
									/* translators: 1: date, 2: time */
									sprintf( __( '%1$s at %2$s', TXTDOMAIN ), get_comment_date(), get_comment_time() )
								)
							);
							
							edit_comment_link( __( 'Edit', TXTDOMAIN ), '<span class="edit-link">', '</span>' ); 
							?>
						</div><!-- .comment-author .vcard -->

						<?php if ( $comment->comment_approved == '0' ) : ?>
						<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', TXTDOMAIN ); ?></em>
						<br />
						<?php endif; ?>

					</footer>

					<div class="comment-content"><?php comment_text(); ?></div>

					<div class="reply">
						<?php 
						$reply_text = aero_get_option('reply_text');
						comment_reply_link( array_merge( $args, array( 'reply_text' => __( $reply_text , TXTDOMAIN ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); 
						?>
					</div><!-- .reply -->
					
			</article><!-- #comment-## -->
			
			<?php
			break;
			
		endswitch;
	}
	
	endif; // end check function.
?>