<?php
/** 
 *	Aero Theme Options Page
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki Aria Gumelar
 *	@version	: 1.0
 *	@link		: http://www.my-themes.com
 *	@credits	: Devin Price, http://wptheming.com/
 *	@copyright	: Copyright (c) 2012, http://www.my-themes.com
 *	--------------------------------------------------------------------------- */

/*	Make sure we don't expose any info if called directly
 *	---------------------------------------- */
	if ( !function_exists( 'add_action' ) ) {
		echo "Hi there!  I'm just a little extension, don't mind me.";
		exit;
	}

/*	User Roles Check
 *	---------------------------------------- */
	add_action('init', 'aeroframework_check' );
	
	function aeroframework_check () {
		if ( current_user_can( 'edit_theme_options' ) ) {
		
			add_action('admin_menu', 'aeroframework_add_page');
			add_action('admin_init', 'aeroframework_init');
			add_action('admin_init', 'aeroframework_mlu_init');
			
		}
	}
	
	function aeroframework_page_capability( $capability ) {
		return 'edit_theme_options';
	}

/*	Load Data Sanitazion
 *	---------------------------------------- */
	add_action('init', 'aeroframework_load_sanitization' );

	function aeroframework_load_sanitization() {
		require_once dirname( __FILE__ ) . '/admin-sanitize.php';
	}
	
/*	Create Settings
 *	---------------------------------------- */
	function aeroframework_init() {

		require_once dirname( __FILE__ ) . '/admin-interface.php';
		require_once dirname( __FILE__ ) . '/media-uploader.php';
		require_once dirname( __FILE__ ) . '/options.php';

		$aeroframework_settings = get_option('aeroframework' );
	
		aeroframework_option_name();
	
		if ( isset($aeroframework_settings['id']) ) {
			$option_name = $aeroframework_settings['id'];
		} else {
			$option_name = 'aeroframework';
		}
	
		if ( ! get_option($option_name) ) {
			aeroframework_setdefaults();
		}
	
		register_setting( 'aeroframework', $option_name, 'aeroframework_validate' );
	}
	
/*	Adds Default Setting
 *	---------------------------------------- */
	function aeroframework_setdefaults() {

		$aeroframework_settings = get_option('aeroframework');
		$option_name = $aeroframework_settings['id'];
	
		if ( isset($aeroframework_settings['knownoptions']) ) {
			$knownoptions =  $aeroframework_settings['knownoptions'];
			if ( !in_array($option_name, $knownoptions) ) {
				array_push( $knownoptions, $option_name );
				$aeroframework_settings['knownoptions'] = $knownoptions;
				update_option('aeroframework', $aeroframework_settings);
			}
		} else {
			$newoptionname = array($option_name);
			$aeroframework_settings['knownoptions'] = $newoptionname;
			update_option('aeroframework', $aeroframework_settings);
		}
	
		$options = aeroframework_options();
	
		$values = aero_get_default_values();
	
		if ( isset($values) ) {
			add_option( $option_name, $values );
		}	
	}
 
/*	Create Menu Page
 *	---------------------------------------- */
	if ( !function_exists( 'aeroframework_add_page' ) ) {
	function aeroframework_add_page() {
		
		$aero_page = add_theme_page( THEMENAME . ' Options', THEMENAME . ' Options', 'edit_theme_options', 'aero-framework','aeroframework_page');
		add_theme_page('Sidebar Manager', 'Sidebar Manager', 'edit_theme_options', 'aero-sidebar-manager', 'aero_sidebar_manager');
		
		// Load the required CSS and javscript
		add_action('admin_enqueue_scripts', 'aeroframework_load_scripts');
		add_action('admin_print_styles-' . $aero_page, 'aeroframework_load_styles' );
	}
	}

/*	Load Admin Styles
 *	---------------------------------------- */
	function aeroframework_load_styles() {
		wp_enqueue_style('admin-style', AERO_FRAMEWORK_DIRECTORY.'stylesheets/admin-style.css');
		wp_enqueue_style('color-picker', AERO_FRAMEWORK_DIRECTORY.'stylesheets/colorpicker.css');
	}	

/*	Load Admin Scripts
 *	---------------------------------------- */
	function aeroframework_load_scripts($hook) {
		if ( 'appearance_page_aero-framework' != $hook )
		return;
		wp_enqueue_script('jquery-ui-core');
		wp_enqueue_script('color-picker', AERO_FRAMEWORK_DIRECTORY.'javascripts/colorpicker.js', array('jquery'));
		wp_enqueue_script('aero-custom', AERO_FRAMEWORK_DIRECTORY.'javascripts/admin.js', array('jquery'));
	
		add_action('admin_head', 'aero_admin_head');
	}

/*	Hook Inline Script
 *	---------------------------------------- */
	function aero_admin_head() {
		do_action( 'aeroframework_custom_scripts' );
	}

/*	Page Structure
 *	---------------------------------------- */
	if ( !function_exists( 'aeroframework_page' ) ) :
	function aeroframework_page() {
		settings_errors(); 
	?>
		
	<div id="aero-container">	
		<form action="options.php" method="post">
			<div id="aero-inner-left">
				<?php settings_fields('aeroframework'); ?>
				<div id="logo">
					<img src="<?php echo AERO_FRAMEWORK_DIRECTORY; ?>images/aero.png"/>
				</div>
					
				<?php $return = aeroframework_fields(); ?>
				<ul id="aero-menu">
					<?php echo $return[1]; ?>				
				</ul>
			</div>
			
			<div id="aero-inner-right">
				<?php echo $return[0]; /* Settings */ ?>
					
				<div class="clear"></div>
					
				<div id="aero-footer">
					<input type="submit" class="save-button" name="update" value="<?php esc_attr_e( 'Save Options', TXTDOMAIN ); ?>" />
					<input type="submit" class="reset-button" name="reset" value="<?php esc_attr_e( 'Restore Defaults', TXTDOMAIN ); ?>" onclick="return confirm( '<?php print esc_js( __( 'Click OK to reset. Any theme settings will be lost!', TXTDOMAIN ) ); ?>' );" />
					<div class="clear"></div>
				</div>
				
			</div><!--#aero-inner-right-->
		</form>
			
		<div class="clear"></div>
	</div>
		
	<?php
	}
	endif;
	
/*	Validate Data
 *	---------------------------------------- */
	function aeroframework_validate( $input ) {
	
		if ( isset( $_POST['reset'] ) ) {
			add_settings_error( 'aero-framework', 'restore_defaults', __( 'Default options restored.', TXTDOMAIN ), 'updated fade' );
			return aero_get_default_values();
		}

		if ( isset( $_POST['update'] ) ) {
			$clean = array();
			$options = aeroframework_options();
			foreach ( $options as $option ) {

				if ( ! isset( $option['id'] ) ) {
					continue;
				}

				if ( ! isset( $option['type'] ) ) {
					continue;
				}

				$id = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower( $option['id'] ) );

				if ( 'checkbox' == $option['type'] && ! isset( $input[$id] ) ) {
					$input[$id] = '0';
				}

				if ( 'multicheck' == $option['type'] && ! isset( $input[$id] ) ) {
					foreach ( $option['options'] as $key => $value ) {
						$input[$id][$key] = '0';
					}
				}
				
				if ( has_filter( 'aero_sanitize_' . $option['type'] ) ) {
					$clean[$id] = apply_filters( 'aero_sanitize_' . $option['type'], $input[$id], $option );
				}
			}

			add_settings_error( 'aero-framework', 'save_options', __( 'Options saved.', TXTDOMAIN ), 'updated fade' );
		
			return $clean;
		}

		return aero_get_default_values();
	}

/*	Get Default Values
 *	---------------------------------------- */
	function aero_get_default_values() {
		
		$output = array();
		$config = aeroframework_options();
		
		foreach ( (array) $config as $option ) {
			
			if ( ! isset( $option['id'] ) ) {
				continue;
			}
			
			if ( ! isset( $option['std'] ) ) {
				continue;
			}
			
			if ( ! isset( $option['type'] ) ) {
				continue;
			}
			
			if ( has_filter( 'aero_sanitize_' . $option['type'] ) ) {
				$output[$option['id']] = apply_filters( 'aero_sanitize_' . $option['type'], $option['std'], $option );
			}
			
		}
		return $output;
	}

?>