<?php
/** 
 *	Aero Admin Sanitize Data
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki Aria Gumelar
 *	@version	: 1.0
 *	@link		: http://www.my-themes.com
 *	@credits	: Devin Price, http://wptheming.com/
 *	@copyright	: Copyright (c) 2012, http://www.my-themes.com
 *	--------------------------------------------------------------------------- */
 
/*	Text Input Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_text', 'sanitize_text_field' );

/*	Textarea Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_textarea', 'aero_sanitize_textarea' );
	
	function aero_sanitize_textarea($input) {
		$output = $input;
		return $output;
	}

/*	Select Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_select', 'aero_sanitize_enum', 10, 2);

/*	Radio Input Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_radio', 'aero_sanitize_enum', 10, 2);
	
/*	Images Selector Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_images', 'aero_sanitize_enum', 10, 2);

/*	Checkbox Input Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_checkbox', 'aero_sanitize_checkbox' );
	
	function aero_sanitize_checkbox( $input ) {
		if ( $input ) {
			$output = "1";
		} else {
			$output = "0";
		}
		return $output;
	}
	
/*	Multicheck Input Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_multicheck', 'aero_sanitize_multicheck', 10, 2 );
	
	function aero_sanitize_multicheck( $input, $option ) {
		$output = '';
		if ( is_array( $input ) ) {
			foreach( $option['options'] as $key => $value ) {
				$output[$key] = "0";
			}
			foreach( $input as $key => $value ) {
				if ( array_key_exists( $key, $option['options'] ) && $value ) {
					$output[$key] = "1"; 
				}
			}
		}
		return $output;
	}

/*	Color Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_color', 'aero_sanitize_hex' );

	function aero_sanitize_hex( $hex, $default = '' ) {
		if ( aero_validate_hex( $hex ) ) {
			return $hex;
		}
		return $default;
	}
	
	function aero_validate_hex( $hex ) {
		$hex = trim( $hex );
	
		if ( 0 === strpos( $hex, '#' ) ) {
			$hex = substr( $hex, 1 );
		} elseif ( 0 === strpos( $hex, '%23' ) ) {
			$hex = substr( $hex, 3 );
		}
	
		if ( 0 === preg_match( '/^[0-9a-fA-F]{6}$/', $hex ) ) {
			return false;
		} else {
			return true;
		}
	}

/*	Upload Sanitize 
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_upload', 'aero_sanitize_upload' );
	
	function aero_sanitize_upload( $input ) {
		$output = '';
		$filetype = wp_check_filetype($input);
		
		if ( $filetype["ext"] ) {
			$output = $input;
		}
		return $output;
	}
 
/*	Background Sanitize 
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_background', 'aero_sanitize_background' );
	
	function aero_sanitize_background( $input ) {
		$output = wp_parse_args( $input, array(
			'color' => '',
			'image'  => '',
			'repeat'  => 'repeat',
			'position' => 'top center',
			'attachment' => 'scroll'
		));

		$output['color'] = apply_filters( 'aero_sanitize_hex', $input['color'] );
		$output['image'] = apply_filters( 'aero_sanitize_upload', $input['image'] );
		$output['repeat'] = apply_filters( 'aero_background_repeat', $input['repeat'] );
		$output['position'] = apply_filters( 'aero_background_position', $input['position'] );
		$output['attachment'] = apply_filters( 'aero_background_attachment', $input['attachment'] );

		return $output;
	}
	
	add_filter( 'aero_background_repeat', 'aero_sanitize_background_repeat' );
	
	function aero_sanitize_background_repeat( $value ) {
		$recognized = aero_recognized_background_repeat();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'aero_default_background_repeat', current( $recognized ) );
	}

	add_filter( 'aero_background_position', 'aero_sanitize_background_position' );
	
	function aero_sanitize_background_position( $value ) {
		$recognized = aero_recognized_background_position();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'aero_default_background_position', current( $recognized ) );
	}
	
	add_filter( 'aero_background_attachment', 'aero_sanitize_background_attachment' );
	
	function aero_sanitize_background_attachment( $value ) {
		$recognized = aero_recognized_background_attachment();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'aero_default_background_attachment', current( $recognized ) );
	}
	
	function aero_recognized_background_repeat() {
		return array(
			'none'     => 'No Repeat',
			'repeat-x' => 'Repeat Horizontally',
			'repeat-y' => 'Repeat Vertically',
			'repeat'   => 'Repeat All',
		);
	}

	function aero_recognized_background_position() {
		return array(
			'top left' => 'Top Left',
			'top center' => 'Top Center',
			'top right' => 'Top Right',
			'center left' => 'Middle Left',
			'center center' => 'Middle Center',
			'center right' => 'Middle Right',
			'bottom left' => 'Bottom Left',
			'bottom center' => 'Bottom Center',
			'bottom right' => 'Bottom Right'
		);
	}

	function aero_recognized_background_attachment() {
		return array(
			'scroll' => 'Scroll',
			'fixed' => 'Fixed'
		);
	}
	
/*	Typography Sanitize
 *	---------------------------------------- */
	add_filter( 'aero_sanitize_typography', 'aero_sanitize_typography' );
	
	function aero_sanitize_typography( $input ) {
		$output = wp_parse_args( $input, array(
			'size'  => '',
			'face'  => '',
			'style' => '',
			'color' => ''
		));

		$output['size']  = apply_filters( 'aero_font_size', $output['size'] );
		$output['face']  = apply_filters( 'aero_font_face', $output['face'] );
		$output['style'] = apply_filters( 'aero_font_style', $output['style'] );
		$output['color'] = apply_filters( 'aero_color', $output['color'] );

		return $output;
	}
	
	add_filter( 'aero_sanitize_typography_heading', 'aero_sanitize_typography_heading' );
	
	function aero_sanitize_typography_heading( $input ) {
		$output = wp_parse_args( $input, array(
			'face'  => '',
			'style' => '',
			'color' => ''
		));

		$output['face']  = apply_filters( 'aero_font_face', $output['face'] );
		$output['style'] = apply_filters( 'aero_font_style', $output['style'] );
		$output['color'] = apply_filters( 'aero_color', $output['color'] );

		return $output;
	}
	
	function aero_sanitize_font_size( $value ) {
		$recognized = aero_recognized_font_sizes();
		$value = preg_replace('/px/','', $value);
		if ( in_array( (int) $value, $recognized ) ) {
				return (int) $value;
		}
		return (int) apply_filters( 'aero_default_font_size', $recognized );
	}

	add_filter( 'aero_font_face', 'aero_sanitize_font_face' );
	
	function aero_recognized_font_sizes() {
		$sizes = range( 9, 71 );
		$sizes = apply_filters( 'aero_recognized_font_sizes', $sizes );
		$sizes = array_map( 'absint', $sizes );
		return $sizes;
	}
	
	/* ------------------------------------------------------------------------- */
	
	function aero_sanitize_font_style( $value ) {
		$recognized = aero_recognized_font_styles();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'aero_default_font_style', current( $recognized ) );
	}
	
	add_filter( 'aero_font_style', 'aero_sanitize_font_style' );
	
	function aero_recognized_font_styles() {
		$default = array(
			'normal' => 'Normal',
			'italic' => 'Italic',
			'bold' => 'Bold'
		);
		
		return apply_filters( 'aero_recognized_font_styles', $default );
	}

	/* ------------------------------------------------------------------------- */
	
	function aero_sanitize_font_face( $value ) {
		$recognized = aero_recognized_font_faces();
		if ( array_key_exists( $value, $recognized ) ) {
			return $value;
		}
		return apply_filters( 'aero_default_font_face', current( $recognized ) );
	}

	add_filter( 'aero_font_face', 'aero_sanitize_font_face' );
	
	function aero_recognized_font_faces() {
		$default = array(
			'arial' => 'Arial',
			'verdana' => 'Verdana',
			'trebuchet' => 'Trebuchet',
			'georgia' => 'Georgia',
			'times' => 'Times New Roman',
			'tahoma' => 'Tahoma',
			'palatino' => 'Palatino',
		);
		
		return apply_filters( 'aero_recognized_font_faces', $default );
	}
	
/*	Check that the key value sent is valid 
 *	---------------------------------------- */
	function aero_sanitize_enum( $input, $option ) {
		$output = '';
		if ( array_key_exists( $input, $option['options'] ) ) {
			$output = $input;
		}
		return $output;
	}
	
?>