<?php
/** 
 *	Register Portfolio Post Type
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki Aria Gumelar
 *	@version	: 1.0
 *	@link		: http://www.my-themes.com
 *	@copyright	: Copyright (c) 2012, http://www.my-themes.com
 *	--------------------------------------------------------------------------- */
 
/*	Register Portfolio Post Type
 *	---------------------------------------- */	
	function portfolio_register() {
	
		$labels = array(
			'name' => __( 'Portfolio'), 
			'singular_name' => __('Portfolio'),
			'rewrite' => array( 'slug' => __( 'portfolio' ) ),
			'add_new' => _x('Add Item', 'portfolio'), 
			'edit_item' => __('Edit Portfolio Item'),
			'new_item' => __('New Portfolio Item'), 
			'view_item' => __('View Portfolio'),
			'search_items' => __('Search Portfolio'), 
			'not_found' =>  __('No Portfolio Items Found'),
			'not_found_in_trash' => __('No Portfolio Items Found In Trash'),
			'parent_item_colon' => '' 
		);
	
		$args = array(
			'labels' => $labels, 
			'public' => true, 
			'publicly_queryable' => true, 
			'show_ui' => true, 
			'query_var' => true, 
			'rewrite' => true, 
			'capability_type' => 'post', 
			'hierarchical' => false, 
			'menu_position' => null, 
			'supports' => array('title', 'thumbnail', 'excerpt', 'editor', 'comments')
		);
	
		register_post_type( __( 'portfolio' ) , $args );
		
	}

/*	Create Custom Message
 *	---------------------------------------- */
	function portfolio_messages($messages) {
		global $post;
		
		$messages[__( 'portfolio' )] = array(
			0 => '',
			1 => sprintf(__('Portfolio Updated. <a href="%s">View portfolio</a>'), esc_url(get_permalink($post->ID))),
			2 => __('Custom Field Updated.'),
			3 => __('Custom Field Deleted.'),
			4 => __('Portfolio Updated.'),
			5 => isset($_GET['revision']) ? sprintf( __('Portfolio Restored To Revision From %s'), wp_post_revision_title((int)$_GET['revision'],false)) : false,
			6 => sprintf(__('Portfolio Published. <a href="%s">View Portfolio</a>'), esc_url(get_permalink($post->ID))),
			7 => __('Portfolio Saved.'),
			8 => sprintf(__('Portfolio Submitted. <a target="_blank" href="%s">Preview Portfolio</a>'), esc_url( add_query_arg('preview','true',get_permalink($post->ID)))),
			9 => sprintf(__('Portfolio Scheduled For: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Portfolio</a>'),date_i18n( __( 'M j, Y @ G:i' ),strtotime($post->post_date)), esc_url(get_permalink($post->ID))),
			10 => sprintf(__('Portfolio Draft Updated. <a target="_blank" href="%s">Preview Portfolio</a>'), esc_url( add_query_arg('preview','true',get_permalink($post->ID)))),
		);
		
		return $messages;
	}

/*	Register Portfolio Taxonomy
 *	---------------------------------------- */
	function portfolio_taxonomy() {
	
		register_taxonomy(__( "portfolio_type" ), 
			array(__( "portfolio" )), 
			array(
				"hierarchical" => true, 
				"label" => __( "Portfolio Type" ), 
				"singular_label" => __( "Portfolio Type" ), 
				"rewrite" => array(
					'slug' => 'portfolio-type', 
					'hierarchical' => true
				)
			)
		); 
		
	}
	
/*	Add more columns
 *	---------------------------------------- */
	function prod_edit_columns($columns) {
		
		$newcolumns = array(
			"cb" => "<input type=\"checkbox\" />",
			"title" => "Title",
			"portfolio_type" => "Type"
		);
	
		$columns= array_merge($newcolumns, $columns);
	
		return $columns;
	}

	function prod_custom_columns($column) {
		
		global $post;
		
		switch ($column) {
			
			case 'portfolio_type':
				echo get_the_term_list($post->ID, 'portfolio_type', '', ', ','');
			break;
		}
	}
	
/*	Add Action
 *	---------------------------------------- */
	add_action('init', 'portfolio_register');
	add_action('init', 'portfolio_taxonomy', 0 );
	add_filter('post_updated_messages', 'portfolio_messages');
	add_filter('manage_edit-portfolio_columns', 'prod_edit_columns');
	add_action('manage_posts_custom_column',  'prod_custom_columns');
	
?>