<?php
/** 
 *	Flickr Photostream Widget
 * 	---------------------------------------------------------------------------
 *	@author 	: Rifki Aria Gumelar
 *	@version	: 1.0
 *	@link		: http://www.my-themes.com
 *	@copyright	: Copyright (c) 2012, http://www.my-themes.com
 *	--------------------------------------------------------------------------- */
 
/*	Register Widget
 *	---------------------------------------- */
	add_action( 'widgets_init', 'register_aero_flickr_widget' );

	function register_aero_flickr_widget() {
		register_widget( 'aero_flickr_widget' );
	}
 
/*	Widget Class
 *	---------------------------------------- */ 
	class aero_flickr_widget extends WP_Widget {
		
		/* Constructor */
		function aero_flickr_widget() {
			$widget_ops = array( 'classname' => 'flickr-widget', 'description' => __('A widget to display your flickr photostream.', TXTDOMAIN) );
			$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'aero-flickr-widget' );
			$this->WP_Widget( 'aero-flickr-widget', 'Flickr Widget', $widget_ops, $control_ops );
		}
		
		/* Widget display */
		function widget( $args, $instance ) {
			extract( $args );

			$title = apply_filters('widget_title', $instance['title'] );
			$flickr_id = $instance['flickr_id'];
			$photo_count = $instance['photo_count'];
			$type = $instance['type'];
			$order = $instance['order'];
		
			echo $before_widget . "\n";
			if ( $title )
			echo $before_title . $title . $after_title . "\n"; 
		
			echo '<div class="flickr-photos clearfix">' . "\n";
			if ( $flickr_id )
			echo '<script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count='. $photo_count .'&amp;display='. $order .'&amp;size=s&amp;layout=x&amp;source='. $type .'&amp;'. $type .'='. $flickr_id .'"></script>' . "\n";
		
			echo '<div class="clear"></div>' . "\n";
			echo '</div>' . "\n";
			echo $after_widget . "\n\n";
		}
		
		/* Update widget settings */
		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			$instance['title'] 		= strip_tags( $new_instance['title'] );
			$instance['flickr_id']	= strip_tags( $new_instance['flickr_id'] );
			$instance['photo_count'] = $new_instance['photo_count'];
			$instance['type']		= $new_instance['type'];
			$instance['order']		= $new_instance['order'];
			
			return $instance;
		}
		
		/* Widget form */
		function form( $instance ) {
			
			$defaults = array( 
				'title' 	=> 'Flickr',
				'flickr_id'	=> '',
				'photo_count' => '8',
				'type' 		=> 'user',
				'order' 	=> 'latest'
			);
			
			$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', TXTDOMAIN) ?></label>
				<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
			</p>
		
			<p>
				<label for="<?php echo $this->get_field_id( 'flickr_id' ); ?>"><?php _e('Flickr ID:', TXTDOMAIN) ?></label>
				<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'flickr_id' ); ?>" name="<?php echo $this->get_field_name( 'flickr_id' ); ?>" value="<?php echo $instance['flickr_id']; ?>" />
			</p>
		
			<p>
			<label for="<?php echo $this->get_field_id( 'photo_count' ); ?>"><?php _e('Number of Photos:', TXTDOMAIN) ?></label>
			<select id="<?php echo $this->get_field_id( 'photo_count' ); ?>" name="<?php echo $this->get_field_name( 'photo_count' ); ?>" class="widefat">
            	<optgroup label="Sidebar">
                    <option <?php if ( '4' == $instance['photo_count'] ) echo 'selected="selected"'; ?>>4</option>
                    <option <?php if ( '8' == $instance['photo_count'] ) echo 'selected="selected"'; ?>>8</option>
                    <option <?php if ( '12' == $instance['photo_count'] ) echo 'selected="selected"'; ?>>12</option>
                </optgroup>
                <optgroup label="Footer">
                    <option <?php if ( '3' == $instance['photo_count'] ) echo 'selected="selected"'; ?>>3</option>
                    <option <?php if ( '6' == $instance['photo_count'] ) echo 'selected="selected"'; ?>>6</option>
                    <option <?php if ( '9' == $instance['photo_count'] ) echo 'selected="selected"'; ?>>9</option>
                </optgroup>
			</select>
			</p>
		
			<p>
				<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e('Type (user or group):', TXTDOMAIN) ?></label>
				<select id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" class="widefat">
					<option <?php if ( 'user' == $instance['type'] ) echo 'selected="selected"'; ?>>user</option>
					<option <?php if ( 'group' == $instance['type'] ) echo 'selected="selected"'; ?>>group</option>
				</select>
			</p>
		
			<p>
				<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e('Display (random or latest):', TXTDOMAIN) ?></label>
				<select id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>" class="widefat">
					<option <?php if ( 'random' == $instance['order'] ) echo 'selected="selected"'; ?>>random</option>
					<option <?php if ( 'latest' == $instance['order'] ) echo 'selected="selected"'; ?>>latest</option>
				</select>
			</p>
			
			<?php 
		}
		
	}
 
?>